@@ -226,12 +226,16 @@ int play() {
     oldtimes = timenow();
 
     starttime = timenow();
-
+    input[0]=0x00;
 
     while (misses < 10 && escend < 1) {
 	/*
 	   while ((timenow()) < (oldtimes + 30 - warp)||pause) { */
 	while ((timenow()) < (oldtimes + (1 / rate) * 100) || pause) {
+	
+	    /* debug: */ 
+	    //mvprintw(24,1,"%d %d",inputpos,strlen(input));
+
 	    if ((nappi = getch()) != ERR) {
 		nappi = clower(nappi);
 
@@ -241,7 +245,10 @@ int play() {
 			if ((inputpos > 0) && (!pause)) {
 			    mvprintw(23, inputpos + 1, " ");
 			    mvprintw(23, inputpos + 1, "");
+			    input[inputpos] = 0x00;
 			    inputpos--;
+			    input[inputpos] = 0x00;
+
 			}
 			break;
 		    }
@@ -273,6 +280,15 @@ int play() {
 			}
 			break;
 		    }
+		case 21:
+		    {
+			if ((inputpos > 0) && (!pause)) {
+				inputpos=0;
+				input[0] = 0x00;
+				mvprintw(23, 2, "                   ");
+			}
+			break;
+		    }
 		case 32:
 		case 10:
 		    {
@@ -301,6 +317,18 @@ int play() {
 			    inputpos = 0;
 			    mvprintw(23, 2, "                   ");
 			}
+			break;
+		    }
+		case 11: 
+		    {
+			if (strlen(input)>inputpos && (!pause)) {
+				for (i=inputpos;i<19;i++) {
+					input[i]=0x00;
+		                        mvprintw(23,i + 2, " ");
+				}
+				mvprintw(23,inputpos+2,"");
+			}
+			
 			break;
 		    }
 		case 8:
@@ -308,7 +336,40 @@ int play() {
 			if ((inputpos > 0) && (!pause)) {
 			    mvprintw(23, inputpos + 1, " ");
 			    mvprintw(23, inputpos + 1, "");
+			    input[inputpos] = 0x00;
 			    inputpos--;
+			    input[inputpos] = 0x00;
+			}
+			break;
+		    }
+		case 6:
+		    {
+			if ((inputpos < 19) && (strlen(input)>inputpos) && (!pause)) {
+				inputpos++;
+				mvprintw(23,inputpos + 2,"");
+			}
+			break;
+		    }
+		case 5:
+		    {
+			if ((inputpos != strlen(input)) && (!pause)) {
+				inputpos=strlen(input);
+				mvprintw(23,inputpos + 2,"");
+			}
+			break;
+		    }
+		case 2: 
+		    {
+			if ((inputpos > 0) && (!pause)) {
+				inputpos--;
+				mvprintw(23,inputpos + 2,"");
+			}
+			break;
+		    }
+		case 1:
+		    {
+			if ((inputpos > 0) && (!pause)) {
+				inputpos=0;
 			}
 			break;
 		    }
@@ -318,8 +379,8 @@ int play() {
 			    nappaykset++;
 			if ((inputpos < 19) && (!pause)) {
 			    mvprintw(23, 2 + inputpos, "%c", nappi);
+			    if (inputpos==strlen(input)) input[inputpos + 1] = 0x00;
 			    input[inputpos] = nappi;
-			    input[inputpos + 1] = 0x00;
 			    inputpos++;
 			    if (opt.cheat) {
 				for (i = 0; i < 22; i++)
@@ -665,8 +726,9 @@ int main(int argc, char *argv[]) {
 
     clear();
     drawscreen();
-    mvprintw(15,20, "NOTE THIS VERSION HAS NEW WAY TO CALCULATE SPEED!");
-    mvprintw(16,26, "SCORES ARE NOT THE SAME AS THEY WERE");
+    /* THIS IS OLD NEWS - LEFT HERE TO PUT SOME FUTURE NEWS IN */
+    // mvprintw(15,20, "NOTE THIS VERSION HAS NEW WAY TO CALCULATE SPEED!");
+    // mvprintw(16,26, "SCORES ARE NOT THE SAME AS THEY WERE");
     drawmenu();
 
 
